<?php

namespace EventPortal\Http\Controllers\Admin;

use EventPortal\Domain\Agenda\Actions\CreateSession;
use EventPortal\Domain\Agenda\Actions\DeleteSession;
use EventPortal\Domain\Agenda\Actions\UpdateSession;
use EventPortal\Domain\Agenda\Models\Pathway;
use EventPortal\Domain\Agenda\Models\Session;
use EventPortal\Http\Controllers\Controller;
use Facades\EventPortal\Domain\Agenda\Agendas;
use Illuminate\Http\JsonResponse;

class SessionController extends Controller
{
    public function store(Pathway $pathway, CreateSession $createSession): JsonResponse
    {
        $createSession->execute($pathway, $pathway->agenda->event, request()->input());

        toast()->success(trans('session.created'));

        return response()->json([
            'success' => true,
            'agendas' => Agendas::forEvent($pathway->agenda->event),
        ]);
    }

    public function update(Session $session, UpdateSession $updateSession): JsonResponse
    {
        $updateSession->execute($session, request()->input());

        toast()->success(trans('session.updated'));

        return response()->json([
            'success' => true,
            'agendas' => Agendas::forEvent($session->pathway->agenda->event),
        ]);
    }

    public function delete(Session $session, DeleteSession $deleteSession): JsonResponse
    {
        $deleteSession->execute($session);

        toast()->success(trans('role.deleted'));

        return response()->json([
            'success' => true,
            'agendas' => Agendas::forEvent($session->pathway->agenda->event),
        ]);
    }
}
