<?php

namespace EventPortal\Tests\Support\Traits;

use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Speaker\Models\Speaker;
use Illuminate\Support\Arr;

trait InteractsWithEventSpeakers
{
    public function assertEventHasSpeaker(Event $event, Speaker $speaker): self
    {
        $this->assertDatabaseHas('event_speaker', [
            'speaker_id' => $speaker->id,
            'event_id' => $event->id,
        ]);

        return $this;
    }

    /**
     * @param Speaker|array<Speaker> $speakers
     */
    public function assertEventHasSpeakers(Event $event, $speakers): self
    {
        foreach (Arr::wrap($speakers) as $speaker) {
            $this->assertEventHasSpeaker($event, $speaker);
        }

        return $this;
    }

    public function assertEventMissingSpeaker(Event $event, Speaker $speaker): self
    {
        $this->assertDatabaseMissing('event_speaker', [
            'speaker_id' => $speaker->id,
            'event_id' => $event->id,
        ]);

        return $this;
    }

    /**
     * @param Speaker|array<Speaker> $speaker
     */
    public function assertEventMissingSpeakers(Event $event, $speakers): self
    {
        foreach (Arr::wrap($speakers) as $speaker) {
            $this->assertEventMissingSpeaker($event, $speaker);
        }

        return $this;
    }
}
